"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const utils_general_1 = require("@energyweb/utils-general");
const PublicIssuer_json_1 = __importDefault(require("../../build/contracts/PublicIssuer.json"));
class PublicIssuer extends utils_general_1.GeneralFunctions {
    constructor(web3, address) {
        const buildFile = PublicIssuer_json_1.default;
        super(address
            ? new web3.eth.Contract(PublicIssuer_json_1.default.abi, address)
            : new web3.eth.Contract(buildFile.abi, buildFile.networks.length > 0 ? buildFile.networks[0] : null));
        this.web3 = web3;
    }
    async initialize(certificateTopic, registryAddress, owner, txParams) {
        const method = this.web3Contract.methods.initialize(certificateTopic, registryAddress, owner);
        return this.send(method, txParams);
    }
    async getAllEvents(eventFilter) {
        return this.web3Contract.getPastEvents('allEvents', this.createFilter(eventFilter));
    }
    async encodeIssue(_from, _to, _deviceId, txParams) {
        return this.web3Contract.methods.encodeIssue(_from, _to, _deviceId).call(txParams);
    }
    async decodeIssue(_data, txParams) {
        return this.web3Contract.methods.decodeIssue(_data).call(txParams);
    }
    async getRequestIssue(_requestIssueId, txParams) {
        return this.web3Contract.methods.getRequestIssue(_requestIssueId).call(txParams);
    }
    async getRequestIssuesForDevice(_deviceId, txParams) {
        return this.web3Contract.methods.getRequestIssuesForDevice(_deviceId).call(txParams);
    }
    async requestIssue(_data, txParams) {
        const method = this.web3Contract.methods.requestIssue(_data);
        return this.send(method, txParams);
    }
    async requestIssueFor(_data, _forAddress, txParams) {
        const method = this.web3Contract.methods.requestIssueFor(_data, _forAddress);
        return this.send(method, txParams);
    }
    async approveIssue(_to, _requestId, _value, _validityData, txParams) {
        const method = this.web3Contract.methods.approveIssue(_to, _requestId, _value, _validityData);
        return this.send(method, txParams);
    }
    async issue(_to, _value, _data, txParams) {
        const method = this.web3Contract.methods.issue(_to, _value, _data);
        return this.send(method, txParams);
    }
    async revokeRequest(_requestId, txParams) {
        const method = this.web3Contract.methods.revokeRequest(_requestId);
        return this.send(method, txParams);
    }
    async revokeCertificate(_certificateId, txParams) {
        const method = this.web3Contract.methods.revokeCertificate(_certificateId);
        return this.send(method, txParams);
    }
    async getRegistryAddress(txParams) {
        return this.web3Contract.methods.getRegistryAddress().call(txParams);
    }
    async version(txParams) {
        return this.web3Contract.methods.version().call(txParams);
    }
}
exports.PublicIssuer = PublicIssuer;
//# sourceMappingURL=PublicIssuer.js.map